@@ -72,9 +72,10 @@ class Plugin(GlancesPlugin):
     stats is a dict: {'version': {...}, 'containers': [{}, {}]}
     """
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the plugin."""
         super(Plugin, self).__init__(args=args,
+                                     config=config,
                                      items_history_list=items_history_list)
 
         # The plgin can be disable using: args.disable_docker
@@ -318,9 +319,8 @@ class Plugin(GlancesPlugin):
         ret = {}
         # Read the stats
         try:
-            # Do not exist anymore with Docker 1.11 (issue #848)
-            # ret['rss'] = all_stats['memory_stats']['stats']['rss']
-            # ret['cache'] = all_stats['memory_stats']['stats']['cache']
+            ret['rss'] = all_stats['memory_stats']['stats']['rss']
+            ret['cache'] = all_stats['memory_stats']['stats']['cache']
             ret['usage'] = all_stats['memory_stats']['usage']
             ret['limit'] = all_stats['memory_stats']['limit']
             ret['max_usage'] = all_stats['memory_stats']['max_usage']
