@@ -23,20 +23,16 @@ import psutil
 import warnings
 
 from glances.logger import logger
-from glances.compat import iteritems
-from glances.plugins.glances_batpercent import Plugin as BatPercentPlugin
-from glances.plugins.glances_hddtemp import Plugin as HddTempPlugin
+from glances.compat import iteritems, to_fahrenheit
+from glances.timer import Counter
+from glances.plugins.sensors.glances_batpercent import Plugin as BatPercentPlugin
+from glances.plugins.sensors.glances_hddtemp import Plugin as HddTempPlugin
 from glances.plugins.glances_plugin import GlancesPlugin
 
 SENSOR_TEMP_UNIT = 'C'
 SENSOR_FAN_UNIT = 'R'
 
 
-def to_fahrenheit(celsius):
-    """Convert Celsius to Fahrenheit."""
-    return celsius * 1.8 + 32
-
-
 class Plugin(GlancesPlugin):
     """Glances sensors plugin.
 
@@ -45,21 +41,30 @@ class Plugin(GlancesPlugin):
     The hard disks are already sorted by name.
     """
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the plugin."""
         super(Plugin, self).__init__(args=args,
+                                     config=config,
                                      stats_init_value=[])
 
+        start_duration = Counter()
+
         # Init the sensor class
+        start_duration.reset()
         self.glancesgrabsensors = GlancesGrabSensors()
+        logger.debug("Generic sensor plugin init duration: {} seconds".format(start_duration.get()))
 
         # Instance for the HDDTemp Plugin in order to display the hard disks
         # temperatures
-        self.hddtemp_plugin = HddTempPlugin(args=args)
+        start_duration.reset()
+        self.hddtemp_plugin = HddTempPlugin(args=args, config=config)
+        logger.debug("HDDTemp sensor plugin init duration: {} seconds".format(start_duration.get()))
 
         # Instance for the BatPercent in order to display the batteries
         # capacities
-        self.batpercent_plugin = BatPercentPlugin(args=args)
+        start_duration.reset()
+        self.batpercent_plugin = BatPercentPlugin(args=args, config=config)
+        logger.debug("Battery sensor plugin init duration: {} seconds".format(start_duration.get()))
 
         # We want to display the stat in the curse interface
         self.display_curse = True
